@@ -3,9 +3,10 @@ package Specio::Constraint::Role::DoesType;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Role::Tiny;
+use Specio::PartialDump qw( partial_dump );
 use Storable qw( dclone );
 
 use Specio::Constraint::Role::Interface;
@@ -47,7 +48,7 @@ sub _wrap_message_generator {
 
             return
                   "Validation failed for $description with value "
-                . Devel::PartialDump->new->dump($value)
+                . partial_dump($value)
                 . '(does not do '
                 . $role . ')';
         };
@@ -75,7 +76,7 @@ Specio::Constraint::Role::DoesType - Provides a common implementation for Specio
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 DESCRIPTION
 
