@@ -3,13 +3,13 @@ package Specio::Constraint::Role::Interface;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Carp qw( confess );
-use Devel::PartialDump;
 use Eval::Closure qw( eval_closure );
 use List::Util 1.33 qw( all any first );
 use Specio::Exception;
+use Specio::PartialDump qw( partial_dump );
 use Specio::TypeChecks qw( is_CodeRef );
 use Sub::Quote qw( quote_sub );
 
@@ -115,7 +115,7 @@ sub _wrap_message_generator {
             my $value       = shift;
 
             return "Validation failed for $description with value "
-                . Devel::PartialDump->new->dump($value);
+                . partial_dump($value);
         };
     }
 
@@ -562,7 +562,7 @@ Specio::Constraint::Role::Interface - The interface all type constraints should
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 DESCRIPTION
 
